agentle.agents.templates.data\_collection
=========================================

.. automodule:: agentle.agents.templates.data_collection

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   collected_data
   field_spec
   progressive_profilling_agent
